#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Inventory script to get the metadata from the Architect service.
"""

import os
import yaml
import click
from architect_client.libarchitect import ArchitectClient


def load_yaml_file(path):
    if os.path.exists(path):
        with open(path, 'r') as f:
            return yaml.safe_load(f)
    return {}


@click.command()
@click.argument('resource_name')
def adapter_ansible_inventory(resource_name):
    config = load_yaml_file('/etc/architect/client.yml')
    inventory_api_url = 'http://{}:{}'.format(config['host'],
                                              config['port'])
    inventory_name = config['project']
    client = ArchitectClient(inventory_api_url, inventory_name)
    data = client.get_data('ansible-inventory', resource_name)
    print(yaml.safe_dump(data))


@click.command()
@click.argument('resource_name')
def adapter_salt_pillar(resource_name):
    config = load_yaml_file('/etc/architect/client.yml')
    inventory_api_url = 'http://{}:{}'.format(config['host'],
                                              config['port'])
    inventory_name = config['project']
    client = ArchitectClient(inventory_api_url, inventory_name)
    raw_data = client.get_data('salt-pillar', resource_name)
    output_data = {}
    for datum_name, datum in raw_data.items():
        output_data[datum_name] = datum['parameters']
    print(yaml.safe_dump(output_data[resource_name]))


@click.command()
@click.argument('resource_name')
def adapter_salt_top(resource_name):
    config = load_yaml_file('/etc/architect/client.yml')
    inventory_api_url = 'http://{}:{}'.format(config['host'],
                                              config['port'])
    inventory_name = config['project']
    client = ArchitectClient(inventory_api_url, inventory_name)
    raw_data = client.get_data('salt-top', resource_name)
    output_data = {}
    for datum_name, datum in raw_data.items():
        output_data[datum_name] = datum['applications']
    print(yaml.safe_dump({'classes': output_data[resource_name]}))
